@@ -1,7 +1,4 @@
-trajectory <- function (object, params, times, t0, ...)            
-  stop("function ",sQuote("trajectory")," is undefined for objects of class ",sQuote(class(object)))
-
-setGeneric('trajectory')                                                                            
+setGeneric("trajectory",function(object,...)standardGeneric("trajectory"))
 
 trajectory.internal <- function (object, params, times, t0, as.data.frame = FALSE, ...) {
 
@@ -45,9 +42,6 @@ trajectory.internal <- function (object, params, times, t0, as.data.frame = FALS
   dim(x0) <- c(nvar,nrep,1)
   dimnames(x0) <- list(statenames,NULL,NULL)
   
-  znames <- object@zeronames
-  if (length(znames)>0) x0[znames,,] <- 0
-
   type <- object@skeleton.type          # map or vectorfield?
   
   if (is.na(type))
@@ -59,9 +53,10 @@ trajectory.internal <- function (object, params, times, t0, as.data.frame = FALS
     
   } else if (type=="vectorfield") {
 
-    ## the 'savelist' contains C-level internals that are needed by 'pomp_vf_eval'
-    ## it prevents garbage collection of these data
-    savelist <- .Call(pomp_desolve_setup,object,x0,params)
+    znames <- object@zeronames
+    if (length(znames)>0) x0[znames,,] <- 0
+
+    .Call(pomp_desolve_setup,object,x0,params)
 
     X <- try(
              ode(
@@ -77,7 +72,7 @@ trajectory.internal <- function (object, params, times, t0, as.data.frame = FALS
              silent=FALSE
              )
 
-    .Call(pomp_desolve_takedown,savelist)
+    .Call(pomp_desolve_takedown)
 
     if (inherits(X,'try-error'))
       stop("trajectory error: error in ODE integrator",call.=FALSE)
@@ -86,15 +81,16 @@ trajectory.internal <- function (object, params, times, t0, as.data.frame = FALS
 
     x <- array(data=t(X[-1,-1]),dim=c(nvar,nrep,ntimes),dimnames=list(statenames,NULL,NULL))
     
+    for (z in znames)
+      for (r in seq_len(ncol(x)))
+        x[z,r,-1] <- diff(x[z,r,])
+    
   } else {
     
     stop("deterministic skeleton not specified")
 
   }
 
-  if (length(znames)>0)
-    x[znames,,-1] <- apply(x[znames,,,drop=FALSE],c(1,2),diff)
-    
   if (as.data.frame) {
     x <- lapply(
                 seq_len(ncol(x)),
