@@ -8,4 +8,6 @@ void R_init_pomp (DllInfo *info) {
   R_RegisterCCallable("pomp","reulermultinom",(DL_FUNC) &reulermultinom);
   R_RegisterCCallable("pomp","deulermultinom",(DL_FUNC) &deulermultinom);
   R_RegisterCCallable("pomp","get_pomp_userdata",(DL_FUNC) &get_pomp_userdata);
+  R_RegisterCCallable("pomp","get_pomp_userdata_int",(DL_FUNC) &get_pomp_userdata_int);
+  R_RegisterCCallable("pomp","get_pomp_userdata_double",(DL_FUNC) &get_pomp_userdata_double);
 }
